import * as Y from 'yjs';
import * as encoding from 'lib0/encoding';
import { Awareness } from 'y-protocols/awareness';
import * as mutex from 'lib0/mutex';
import { CloseEvent, MessageEvent, OpenEvent } from 'ws';
import EventEmitter from './EventEmitter';
export declare enum WebSocketStatus {
    Connecting = "connecting",
    Connected = "connected",
    Disconnected = "disconnected"
}
export interface HocuspocusProviderOptions {
    name: string;
    document: Y.Doc;
    connect: boolean;
    awareness: Awareness;
    parameters: Object<string, string>;
    WebSocketPolyfill: any;
    forceSyncInterval: false | number;
    reconnectTimeoutBase: number;
    maxReconnectTimeout: number;
    messageReconnectTimeout: number;
    onOpen: (event: OpenEvent) => void;
    onConnect: () => void;
    onMessage: (event: MessageEvent) => void;
    onSynced: () => void;
    onDisconnect: (event: CloseEvent) => void;
    onClose: (event: CloseEvent) => void;
    onDestroy: () => void;
    debug: boolean;
}
export declare class HocuspocusProvider extends EventEmitter {
    options: HocuspocusProviderOptions;
    awareness: Awareness;
    document: Y.Doc;
    subscribedToBroadcastChannel: boolean;
    websocket: any;
    shouldConnect: boolean;
    status: WebSocketStatus;
    failedConnectionAttempts: number;
    isSynced: boolean;
    lastMessageReceived: number;
    mux: mutex.mutex;
    intervals: any;
    constructor(options?: Partial<HocuspocusProviderOptions>);
    setOptions(options?: Partial<HocuspocusProviderOptions>): void;
    checkConnection(): void;
    forceSync(): void;
    registerBeforeUnloadEventListener(): void;
    broadcastChannelSubscriber(data: ArrayBuffer): void;
    documentUpdateHandler(update: Uint8Array, origin: any): void;
    awarenessUpdateHandler({ added, updated, removed }: any, origin: any): void;
    get document(): Y.Doc;
    get serverUrl(): any;
    get url(): string;
    get broadcastChannel(): string;
    get synced(): boolean;
    set synced(state: boolean);
    subscribeToBroadcastChannel(): void;
    broadcast(message: any): void;
    send(message: Uint8Array, broadcast: false): void;
    disconnectBroadcastChannel(): void;
    disconnect(): void;
    connect(): void;
    onMessage(event: MessageEvent): void;
    onClose(event: CloseEvent): void;
    createWebSocketConnection(): void;
    onOpen(event: OpenEvent): void;
    receiveMessage(input: Uint8Array, emitSynced: boolean): encoding.Encoder;
    websocketConnectionEstablished(): void;
    destroy(): void;
}
